2026-01-15 Version: 1.1.0
- Support API DescribeCustomerModuleMetaInfo.
- Support API DescribeCustomerModuleOutputInfo.
- Support API DescribeFeatureOption.
- Support API DescribeFeatureTemplateList.
- Support API DescribeModelFeature.
- Support API DescribeModelOssToken.
- Support API DescribeModuleServiceExist.
- Support API DescribeModuleStatus.
- Support API DescribeSafRmmpOrder.
- Support API DescribeServiceAndScene.
- Support API DescribeUserModelList.
- Support API DuplicateModel.
- Support API EditModel.
- Support API IterateModel.
- Support API OfflineModel.
- Support API OnlineModel.
- Support API ParseExpressionParameters.
- Support API PrepublishModel.
- Support API RollbackModel.
- Support API TestModel.
- Support API TestPreModel.
- Support API TestProcessExpression.
- Support API UpdateModuleBasicInfo.
- Support API ValidateModelFile.
- Support API ValidateTestFile.


2026-01-15 Version: 1.1.0
- Support API DescribeCustomerModuleMetaInfo.
- Support API DescribeCustomerModuleOutputInfo.
- Support API DescribeFeatureOption.
- Support API DescribeFeatureTemplateList.
- Support API DescribeModelFeature.
- Support API DescribeModelOssToken.
- Support API DescribeModuleServiceExist.
- Support API DescribeModuleStatus.
- Support API DescribeSafRmmpOrder.
- Support API DescribeServiceAndScene.
- Support API DescribeUserModelList.
- Support API DuplicateModel.
- Support API EditModel.
- Support API IterateModel.
- Support API OfflineModel.
- Support API OnlineModel.
- Support API ParseExpressionParameters.
- Support API PrepublishModel.
- Support API RollbackModel.
- Support API TestModel.
- Support API TestPreModel.
- Support API TestProcessExpression.
- Support API UpdateModuleBasicInfo.
- Support API ValidateModelFile.
- Support API ValidateTestFile.


2026-01-13 Version: 1.0.0
- Generated python 2025-05-21 for safconsole.

